@@ -3,7 +3,7 @@ from __future__ import absolute_import, unicode_literals
 import json
 import logging
 
-import six
+from virtualenv.util.six import ensure_text
 
 
 class Session(object):
@@ -48,7 +48,7 @@ class Session(object):
         self.creator.pyenv_cfg.write()
 
     def _create(self):
-        logging.info("create virtual environment via %s", six.ensure_text(str(self.creator)))
+        logging.info("create virtual environment via %s", ensure_text(str(self.creator)))
         self.creator.run()
         logging.debug(_DEBUG_MARKER)
         logging.debug("%s", _Debug(self.creator))
@@ -77,7 +77,7 @@ class _Debug(object):
         self.creator = creator
 
     def __unicode__(self):
-        return six.ensure_text(repr(self))
+        return ensure_text(repr(self))
 
     def __repr__(self):
         return json.dumps(self.creator.debug, indent=2)
