@@ -2,11 +2,10 @@ from __future__ import absolute_import, unicode_literals
 
 from ._pathlib import Path
 from ._permission import make_exe
-from ._sync import copy, copytree, ensure_dir, link, symlink
+from ._sync import copy, copytree, ensure_dir, symlink
 
 __all__ = (
     "ensure_dir",
-    "link",
     "symlink",
     "copy",
     "copytree",
